A p by p variance-covariance matrix, where p
represents the number of parameters.
If full = FALSE, returns the
variance-covariance matrix of only fixed effect
parameters. If full = TRUE , returns the variance-covariance matrix
for all fitted parameters (including fixed effect parameters and random
effect (co)variances). The variance-covariance matrix
is based on the negative of Hessian matrix, which is extracted from
lme4. If ranpar = "var", the random effects are
parameterized as variance/covariance; If ranpar = "sd",
the random effects are parameterized as standard
deviation/correlation; If ranpar = "theta",
the random effects are parameterized as components of Cholesky decomposition.